@@ -1,5 +1,7 @@
 from shexer.utils.factories.triple_yielders_factory import get_triple_yielder
-from shexer.core.class_profiler import ClassProfiler
+from shexer.core.profiling.class_profiler import ClassProfiler
+from shexer.utils.target_elements import tune_target_classes_if_needed
+from shexer.utils.dict import reverse_keys_and_values
 
 
 def get_class_profiler(target_classes_dict, source_file, list_of_source_files, input_format,
@@ -22,7 +24,8 @@ def get_class_profiler(target_classes_dict, source_file, list_of_source_files, i
                        built_remote_graph=None,
                        built_shape_map=None,
                        remove_empty_shapes=True,
-                       limit_remote_instances=-1):
+                       limit_remote_instances=-1,
+                       inverse_paths=False):
     yielder = get_triple_yielder(source_file=source_file,
                                  list_of_source_files=list_of_source_files,
                                  input_format=input_format,
@@ -44,11 +47,17 @@ def get_class_profiler(target_classes_dict, source_file, list_of_source_files, i
                                  file_target_classes=file_target_classes,
                                  built_remote_graph=built_remote_graph,
                                  built_shape_map=built_shape_map,
-                                 limit_remote_instances=limit_remote_instances)
+                                 limit_remote_instances=limit_remote_instances,
+                                 inverse_paths=inverse_paths)
 
     return ClassProfiler(triples_yielder=yielder,
-                         target_classes_dict=target_classes_dict,
+                         instances_dict=target_classes_dict,
                          instantiation_property_str=instantiation_property_str,
-                         original_target_classes=target_classes,
+                         original_target_classes=None
+                         if target_classes is None
+                         else tune_target_classes_if_needed(
+                             list_target_classes=target_classes,
+                             prefix_namespaces_dict=reverse_keys_and_values(namespaces_dict)),
                          original_shape_map=built_shape_map,
-                         remove_empty_shapes=remove_empty_shapes)
+                         remove_empty_shapes=remove_empty_shapes,
+                         inverse_paths=inverse_paths)
